@@ -16,7 +16,7 @@ class McTotal(object):
 
     def get_multi(self, keys):
         mc_key = self.mc_key
-        mc_key_list = dict([(key,mc_key%key) for key in keys])
+        mc_key_list = dict([(key, mc_key%key) for key in keys])
         result = mc.get_multi(mc_key_list.itervalues())
         r = {}
         for k, mck in mc_key_list.iteritems():
@@ -27,21 +27,30 @@ class McTotal(object):
             r[k] = v
         return r
 
-    def bind_total(self,ins):
-        d = self.get_multi(i.id for i in ins)
-        for i in ins:
-            i.total = d[i.id]
-        return ins
+    def bind(self, xxx_list, property, key="id"):
+        d = []
+        e = []
+        for i in xxx_list:
+            k = getattr(i, key)
+            if k:
+                d.append(k)
+                e.append((k, i))
+            else:
+                i.__dict__[property] = None
 
-    def delete(self,key):
+        r = self.get_multi(set(d))
+        for k, v in e:
+            v.__dict__[property] = r.get(k)
+
+    def delete(self, key):
         mk = self.mc_key%key
         mc.delete(mk)
 
     def get_list(self, keys):
         r = self.get_multi(keys)
-        
+
         return [
-            r.get(i,0) for i in keys
+            r.get(i, 0) for i in keys
         ]
 
 
@@ -56,4 +65,3 @@ class McTotal(object):
             mc.decr(mk)
 
 
-
