@@ -1,6 +1,6 @@
 #coding:utf-8
 from sqlbean.db.query import Query, escape
-from sqlbean.metamodel import cache, lower_name, ModelBase, get_or_create, save
+from sqlbean.metamodel import cache, lower_name, ModelBase, get_or_create, save, get , __eq__
 
 class Model(object):
     '''
@@ -72,7 +72,7 @@ class Model(object):
         
     '''
     __metaclass__ = ModelBase
-
+    __eq__ = __eq__
     debug = False
 
     def __init__(self, *args, **kwargs):
@@ -101,9 +101,6 @@ class Model(object):
                         self._changed.add(name)
         dc[name] = value
 
-    def _get_pk(self):
-        'Returns value of primary key'
-        return getattr(self, self.Meta.pk)
 
     def _get_pk(self):
         'Sets the current value of the primary key'
@@ -131,7 +128,8 @@ class Model(object):
         'Uses SQL INSERT to create new record'
         # if pk field is set, we want to insert it too
         # if pk field is None, we want to auto-create it from lastrowid
-        auto_pk = 1 and (self._get_pk() is None) or 0
+	pk = self._get_pk()
+	auto_pk = 1 and (pk is None) or 0
         fields = [
             f for f in self._fields
             if f != self.Meta.pk or not auto_pk
@@ -141,6 +139,7 @@ class Model(object):
         values = []
         for i in fields:
             v = getattr(self, i, None)
+	    #print i,v
             if v is not None:
                 used_fields.append(escape(i))
                 values.append(v)
@@ -149,9 +148,10 @@ class Model(object):
                 ', '.join(["%s"] * len(used_fields))
         )
         cursor = Query.raw_sql(query, values, self.db)
+	
+	
 
-
-        if self._get_pk() is None:
+        if pk is None:
             self._set_pk(cursor.lastrowid)
         return True
 
@@ -201,19 +201,6 @@ class Model(object):
             conditions=kwargs
         )
 
-    @classmethod
-    def get(cls, __obj_pk=None, **kwargs):
-        if __obj_pk is not None:
-            kwargs = {
-                cls.Meta.pk: __obj_pk
-            }
-        q = Query(model=cls, conditions=kwargs)
-        q = q.execute_query()
-        q = q.fetchone()
-        if q:
-            obj = cls(*q)
-            obj.__dict__['_new_record'] = False
-            return obj
 
     @classmethod
     def count(cls, *args, **kwargs):
@@ -251,7 +238,7 @@ class Model(object):
         finally:
             db.b_commit = True
 
-
+    get = get
     get_or_create = get_or_create
 
     @classmethod
